@@ -14,7 +14,7 @@ use Term::ANSIColor qw/colored/;
 use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 
-our $VERSION  = version->new(1.1.10);
+our $VERSION  = version->new(1.1.11);
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option = (
@@ -94,19 +94,19 @@ sub _sorter {
     $A cmp $B;
 }
 
-my @master;
+my %dest;
 sub unmerged {
-    my ($branch, $master) = @_;
+    my ($source, $dest) = @_;
 
-    if ( ! @master ) {
-        @master = map {/^(.*)\n/; $1} `git log --format=format:%H $master`;
-        die "No master" if !@master;
+    if ( ! $dest{$dest} ) {
+        @{$dest{$dest}} = map {/^(.*)\n/; $1} `git log --format=format:%H $dest`;
+        die "No destination branch commits for '$dest'" if !@{$dest{$dest}};
     }
 
-    my $source_sha = `git log --format=format:%H -n 1 $branch`;
+    my $source_sha = `git log --format=format:%H -n 1 $source`;
     chomp $source_sha;
 
-    return scalar grep {$_ && $_ eq $source_sha} @master;
+    return scalar grep {$_ && $_ eq $source_sha} @{$dest{$dest}};
 }
 
 1;
@@ -119,7 +119,7 @@ git-branch-grep - grep for branch names (and optionally files with them)
 
 =head1 VERSION
 
-This documentation refers to git-branch-grep version 1.1.10
+This documentation refers to git-branch-grep version 1.1.11
 
 =head1 SYNOPSIS
 
@@ -165,6 +165,10 @@ C<git branch (-r|-a)? | grep -P 'regex'>
 
 Executes the git workflow command
 
+=head2 C<unmerged ($source, $dest)>
+
+Check if there are any commits in C<$source> that are not in C<$dest>
+
 =head1 DIAGNOSTICS
 
 =head1 CONFIGURATION AND ENVIRONMENT
